@@ -17,7 +17,6 @@ class PerApplicationStateExtension:
         self._engine = engine
 
         self._state_manager = StateManager([
-            handlers.
             handlers.DefaultTransitionHandler(engine)
         ])
         self._last_details = WindowTracker.BLANK_DETAILS
@@ -26,11 +25,9 @@ class PerApplicationStateExtension:
 
     def start(self) -> None:
         self._on = True
-        self._engine.hook_connect("translated", self.on_translated)
 
     def stop(self) -> None:
         self._on = False
-        self._engine.hook_disconnect("translated", self.on_translated)
 
     def on_window_callback(self, _, details: WindowDetails) -> None:
         if not self._on:
